@@ -332,7 +332,7 @@ class PluginFileLocator(IPluginLocator):
 		self._analyzers = analyzers      # analyzers used to locate plugins
 		if self._analyzers is None:
 			self._analyzers = [PluginFileAnalyzerWithInfoFile("info_ext")]
-		self._default_plugin_info_cls = PluginInfo
+		self._default_plugin_info_cls = plugin_info_cls
 		self._plugin_info_cls_map = {}
 		self._max_size = 1e3*1024 # in octets (by default 1 Mo)
 		self.recursive = True
@@ -433,7 +433,7 @@ class PluginFileLocator(IPluginLocator):
 #						print candidate_infofile
 						plugin_info = self._getInfoForPluginFromAnalyzer(analyzer, dirpath, filename)
 						if plugin_info is None:
-							log.warning("Plugin candidate '%s'  rejected by strategy '%s'" % (candidate_infofile, analyzer.name))
+							log.debug("Plugin candidate '%s'  rejected by strategy '%s'" % (candidate_infofile, analyzer.name))
 							break # we consider this was the good strategy to use for: it failed -> not a plugin -> don't try another strategy
 						# now determine the path of the file to execute,
 						# depending on wether the path indicated is a
@@ -514,6 +514,8 @@ class PluginFileLocator(IPluginLocator):
 		"""
 		Set the list of directories where to look for plugin places.
 		"""
+		if isinstance(directories_list, basestring):
+			raise ValueError("'directories_list' given as a string, but expected to be a list or enumeration of strings")
 		if directories_list is None:
 			directories_list = [os.path.dirname(__file__)]
 		self.plugins_places = directories_list
